Description Usage Arguments Value
Models computes model fits for prior probabilities for each value or
a specific value of the regressand and a specific formula.
1 |
formula |
an object of class |
data |
data frame, list or environment (or object coercible by
|
id.vars |
names of the identification variables for each unit in the
input data set |
targetValue |
value of the regressand (an object of class character). |
maxit |
|
suffix |
parameter for the name of the edited version of the variable under analysis. |
A data.table with four colums named with the LHS
variable of formula, fit.pi, fit.1 and fit.0. The first column contains
every single value of this variable in the input data set data.
The second, third and fourth columns contain a glm object with the fit
of the model for each variable value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.