Definition of the S4 class named categObsPredModelParam for the parameters of
a categorical observation-prediction model in the optimization approach to selective editing.
DataObject of S3 class StQ with the parameters or all data necessary to
compute them.
VarRolesList with components Units, Domains, DesignW,
Regressands, Regressors being character vectors containing the column names
according to their respective role in the model.
modelFitsList with components...
probsData.table with the probabilities from predict...
TrainData.table with the set of data for training the model.
TestData.table with the set of data for testing the model.
1 2 3 4 5 6 7 8 9 10 11 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.