Definition of the S4 class named fitParam for the parameters needed to fit
a categorical observation-prediction model in the optimization approach to selective editing.
edDataobject of class StQ with the edited and validated values.
rawDataobject of class StQ with the raw values.
selParamlist of parameters for the model selection when selection == TRUE
valParamlist of parameters for validation.
1 2 3 4 5 6 7 8 9 10 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.